pub enum QueryMsg {
Config {},
Pair {
asset_infos: [AssetInfo; 2],
},
Pairs {
start_after: Option<[AssetInfo; 2]>,
limit: Option<u32>,
},
Trio {
asset_infos: [AssetInfo; 3],
},
Trios {
start_after: Option<[AssetInfo; 3]>,
limit: Option<u32>,
},
NativeTokenDecimals {
denom: String,
},
}Variants
Config
Retrieves the configuration of the factory.
Pair
Retrieves the info for the pair with the given asset_infos.
Pairs
Retrieves the pairs created by the factory. This query has pagination enabled, querying ten
items by default if not specified otherwise. The max amount of items that can be queried at
once is 30. start_after is the last asset_info of a page.
Trio
Retrieves the info for the trio with the given asset_infos.
Trios
Retrieves the trios created by the factory. This query has pagination enabled, querying ten
items by default if not specified otherwise. The max amount of items that can be queried at
once is 30. start_after is the last asset_info of a page.
NativeTokenDecimals
Retrieves the decimals for the given native or ibc denom.