QueryMsg

Enum QueryMsg 

pub enum QueryMsg {
    Config {},
    Flow {
        flow_identifier: FlowIdentifier,
        start_epoch: Option<u64>,
        end_epoch: Option<u64>,
    },
    Flows {
        start_epoch: Option<u64>,
        end_epoch: Option<u64>,
    },
    Positions {
        address: String,
    },
    Rewards {
        address: String,
    },
    GlobalWeight {
        epoch_id: u64,
    },
    CurrentEpochRewardsShare {
        address: String,
    },
}

Variants



Config

Retrieves the current contract configuration.



Flow

Retrieves a specific flow. If start_epoch and end_epoch are set, the asset_history and emitted_tokens will be filtered to only include epochs within the range. The maximum gap between the start_epoch and end_epoch is 100 epochs.

Fields

flow_identifier: FlowIdentifier

The id of the flow to find.

start_epoch: Option<u64>

If set, filters the asset_history and emitted_tokens to only include epochs from start_epoch.

end_epoch: Option<u64>

If set, filters the asset_history and emitted_tokens to only include epochs until end_epoch.



Flows

Retrieves the current flows. If start_epoch and end_epoch are set, the asset_history and emitted_tokens will be filtered to only include epochs within the range. The maximum gap between the start_epoch and end_epoch is 100 epochs.

Fields

start_epoch: Option<u64>

If set, filters the asset_history and emitted_tokens to only include epochs from start_epoch.

end_epoch: Option<u64>

If set, filters the asset_history and emitted_tokens to only include epochs until end_epoch.



Positions

Retrieves the positions for an address.

Fields

address: String

The address to get positions for.



Rewards

Retrieves the rewards for an address.

Fields

address: String

The address to get all the incentive rewards for.



GlobalWeight

Retrieves the rewards for an address.

Fields

epoch_id: u64

The epoch to get the global weight for.



CurrentEpochRewardsShare

Retrieves the rewards/weight share of an address for the current epoch.

Fields

address: String

The address to query the rewards share for.