pub enum QueryPosition {
OpenPosition {
amount: Uint128,
unbonding_duration: u64,
weight: Uint128,
},
ClosedPosition {
amount: Uint128,
unbonding_timestamp: u64,
weight: Uint128,
},
}Variants
OpenPosition
Represents a position that a user has deposited, but not yet begun to unbond.
Fields
ClosedPosition
Represents a position that a user has initiated the unbonding process on. The position may or may not be withdrawable.