pub struct OpenPosition {
pub amount: Uint128,
pub unbonding_duration: u64,
}Expand description
Represents a position that accumulates flow rewards.
An address can have multiple incentive positions active at once.
Fields
amount: Uint128The amount of LP tokens that are put up to earn incentives.
unbonding_duration: u64Represents the amount of time in seconds the user must wait after unbonding for the LP tokens to be released.