pub struct FeatureToggle {
pub withdrawals_enabled: bool,
pub deposits_enabled: bool,
pub swaps_enabled: bool,
}Expand description
Pool feature toggle
Fields
withdrawals_enabled: booldeposits_enabled: boolswaps_enabled: boolTrait Implementations
Sourceimpl Clone for FeatureToggle
impl Clone for FeatureToggle
Sourcefn clone(&self) -> FeatureToggle
fn clone(&self) -> FeatureToggle
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FeatureToggle
impl Debug for FeatureToggle
Sourceimpl<'de> Deserialize<'de> for FeatureToggle
impl<'de> Deserialize<'de> for FeatureToggle
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FeatureToggle
impl JsonSchema for FeatureToggle
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FeatureToggle
impl PartialEq for FeatureToggle
Sourceimpl Serialize for FeatureToggle
impl Serialize for FeatureToggle
impl StructuralPartialEq for FeatureToggle