pub enum QueryMsg {
Trio {},
Config {},
ProtocolFees {
asset_id: Option<String>,
all_time: Option<bool>,
},
BurnedFees {
asset_id: Option<String>,
},
Pool {},
Simulation {
offer_asset: Asset,
ask_asset: Asset,
},
ReverseSimulation {
ask_asset: Asset,
offer_asset: Asset,
},
}Variants
Trio
Retrieves the info for the trio.
Config
Retrieves the configuration of the pool.
ProtocolFees
Retrieves the protocol fees that have been accrued. If all_time is true, it will return
the fees collected since the inception of the pool. On the other hand, if all_time is set
to false, only the fees that has been accrued by the pool but not collected by the fee
collector will be returned.
BurnedFees
Retrieves the fees that have been burned by the pool.
Pool
Retrieves the pool information.
Simulation
Simulates a swap.
ReverseSimulation
Simulates a reverse swap, i.e. given the ask asset, how much of the offer asset is needed to perform the swap.