pub enum QueryMsg {
Config {},
Flow {
flow_identifier: FlowIdentifier,
start_epoch: Option<u64>,
end_epoch: Option<u64>,
},
Flows {
start_epoch: Option<u64>,
end_epoch: Option<u64>,
},
Positions {
address: String,
},
Rewards {
address: String,
},
GlobalWeight {
epoch_id: u64,
},
CurrentEpochRewardsShare {
address: String,
},
}Variants
Config
Retrieves the current contract configuration.
Flow
Retrieves a specific flow. If start_epoch and end_epoch are set, the asset_history and emitted_tokens will be filtered to only include epochs within the range. The maximum gap between the start_epoch and end_epoch is 100 epochs.
Fields

flow_identifier: FlowIdentifierThe id of the flow to find.
Flows
Retrieves the current flows. If start_epoch and end_epoch are set, the asset_history and emitted_tokens will be filtered to only include epochs within the range. The maximum gap between the start_epoch and end_epoch is 100 epochs.
Fields
Positions
Retrieves the positions for an address.
Rewards
Retrieves the rewards for an address.
GlobalWeight
Retrieves the rewards for an address.
Retrieves the rewards/weight share of an address for the current epoch.